# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_dataset_labels_details import AddDatasetLabelsDetails
from .annotation_format import AnnotationFormat
from .annotation_format_collection import AnnotationFormatCollection
from .annotation_format_summary import AnnotationFormatSummary
from .change_dataset_compartment_details import ChangeDatasetCompartmentDetails
from .create_dataset_details import CreateDatasetDetails
from .dataset import Dataset
from .dataset_collection import DatasetCollection
from .dataset_format_details import DatasetFormatDetails
from .dataset_source_details import DatasetSourceDetails
from .dataset_summary import DatasetSummary
from .delimited_file_type_metadata import DelimitedFileTypeMetadata
from .document_dataset_format_details import DocumentDatasetFormatDetails
from .export_format import ExportFormat
from .generate_dataset_records_details import GenerateDatasetRecordsDetails
from .image_dataset_format_details import ImageDatasetFormatDetails
from .initial_record_generation_configuration import InitialRecordGenerationConfiguration
from .label import Label
from .label_set import LabelSet
from .object_storage_snapshot_export_details import ObjectStorageSnapshotExportDetails
from .object_storage_source_details import ObjectStorageSourceDetails
from .remove_dataset_labels_details import RemoveDatasetLabelsDetails
from .rename_dataset_labels_details import RenameDatasetLabelsDetails
from .snapshot_dataset_details import SnapshotDatasetDetails
from .snapshot_export_details import SnapshotExportDetails
from .text_dataset_format_details import TextDatasetFormatDetails
from .text_file_type_metadata import TextFileTypeMetadata
from .update_dataset_details import UpdateDatasetDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for data_labeling_service services.
data_labeling_service_type_mapping = {
    "AddDatasetLabelsDetails": AddDatasetLabelsDetails,
    "AnnotationFormat": AnnotationFormat,
    "AnnotationFormatCollection": AnnotationFormatCollection,
    "AnnotationFormatSummary": AnnotationFormatSummary,
    "ChangeDatasetCompartmentDetails": ChangeDatasetCompartmentDetails,
    "CreateDatasetDetails": CreateDatasetDetails,
    "Dataset": Dataset,
    "DatasetCollection": DatasetCollection,
    "DatasetFormatDetails": DatasetFormatDetails,
    "DatasetSourceDetails": DatasetSourceDetails,
    "DatasetSummary": DatasetSummary,
    "DelimitedFileTypeMetadata": DelimitedFileTypeMetadata,
    "DocumentDatasetFormatDetails": DocumentDatasetFormatDetails,
    "ExportFormat": ExportFormat,
    "GenerateDatasetRecordsDetails": GenerateDatasetRecordsDetails,
    "ImageDatasetFormatDetails": ImageDatasetFormatDetails,
    "InitialRecordGenerationConfiguration": InitialRecordGenerationConfiguration,
    "Label": Label,
    "LabelSet": LabelSet,
    "ObjectStorageSnapshotExportDetails": ObjectStorageSnapshotExportDetails,
    "ObjectStorageSourceDetails": ObjectStorageSourceDetails,
    "RemoveDatasetLabelsDetails": RemoveDatasetLabelsDetails,
    "RenameDatasetLabelsDetails": RenameDatasetLabelsDetails,
    "SnapshotDatasetDetails": SnapshotDatasetDetails,
    "SnapshotExportDetails": SnapshotExportDetails,
    "TextDatasetFormatDetails": TextDatasetFormatDetails,
    "TextFileTypeMetadata": TextFileTypeMetadata,
    "UpdateDatasetDetails": UpdateDatasetDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceUsage(object):
    """
    The resource usage information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceUsage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operations_insights_warehouse_id:
            The value to assign to the operations_insights_warehouse_id property of this ResourceUsage.
        :type operations_insights_warehouse_id: str

        :param id:
            The value to assign to the id property of this ResourceUsage.
        :type id: str

        :param em_instance_count:
            The value to assign to the em_instance_count property of this ResourceUsage.
        :type em_instance_count: int

        :param targets_count:
            The value to assign to the targets_count property of this ResourceUsage.
        :type targets_count: int

        :param em_instances:
            The value to assign to the em_instances property of this ResourceUsage.
        :type em_instances: list[oci.em_warehouse.models.EmInstancesDetails]

        """
        self.swagger_types = {
            'operations_insights_warehouse_id': 'str',
            'id': 'str',
            'em_instance_count': 'int',
            'targets_count': 'int',
            'em_instances': 'list[EmInstancesDetails]'
        }

        self.attribute_map = {
            'operations_insights_warehouse_id': 'operationsInsightsWarehouseId',
            'id': 'id',
            'em_instance_count': 'emInstanceCount',
            'targets_count': 'targetsCount',
            'em_instances': 'emInstances'
        }

        self._operations_insights_warehouse_id = None
        self._id = None
        self._em_instance_count = None
        self._targets_count = None
        self._em_instances = None

    @property
    def operations_insights_warehouse_id(self):
        """
        **[Required]** Gets the operations_insights_warehouse_id of this ResourceUsage.
        operations Insights Warehouse Identifier


        :return: The operations_insights_warehouse_id of this ResourceUsage.
        :rtype: str
        """
        return self._operations_insights_warehouse_id

    @operations_insights_warehouse_id.setter
    def operations_insights_warehouse_id(self, operations_insights_warehouse_id):
        """
        Sets the operations_insights_warehouse_id of this ResourceUsage.
        operations Insights Warehouse Identifier


        :param operations_insights_warehouse_id: The operations_insights_warehouse_id of this ResourceUsage.
        :type: str
        """
        self._operations_insights_warehouse_id = operations_insights_warehouse_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ResourceUsage.
        Unique identifier that is immutable on creation


        :return: The id of this ResourceUsage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResourceUsage.
        Unique identifier that is immutable on creation


        :param id: The id of this ResourceUsage.
        :type: str
        """
        self._id = id

    @property
    def em_instance_count(self):
        """
        Gets the em_instance_count of this ResourceUsage.
        EmInstanceCount


        :return: The em_instance_count of this ResourceUsage.
        :rtype: int
        """
        return self._em_instance_count

    @em_instance_count.setter
    def em_instance_count(self, em_instance_count):
        """
        Sets the em_instance_count of this ResourceUsage.
        EmInstanceCount


        :param em_instance_count: The em_instance_count of this ResourceUsage.
        :type: int
        """
        self._em_instance_count = em_instance_count

    @property
    def targets_count(self):
        """
        Gets the targets_count of this ResourceUsage.
        EmInstance Target count


        :return: The targets_count of this ResourceUsage.
        :rtype: int
        """
        return self._targets_count

    @targets_count.setter
    def targets_count(self, targets_count):
        """
        Sets the targets_count of this ResourceUsage.
        EmInstance Target count


        :param targets_count: The targets_count of this ResourceUsage.
        :type: int
        """
        self._targets_count = targets_count

    @property
    def em_instances(self):
        """
        Gets the em_instances of this ResourceUsage.
        List of emInstances


        :return: The em_instances of this ResourceUsage.
        :rtype: list[oci.em_warehouse.models.EmInstancesDetails]
        """
        return self._em_instances

    @em_instances.setter
    def em_instances(self, em_instances):
        """
        Sets the em_instances of this ResourceUsage.
        List of emInstances


        :param em_instances: The em_instances of this ResourceUsage.
        :type: list[oci.em_warehouse.models.EmInstancesDetails]
        """
        self._em_instances = em_instances

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .url_pattern import UrlPattern
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SimpleUrlPattern(UrlPattern):
    """
    Pattern describing an http/https URL or set thereof
    as a concatenation of optional host component and optional path component.

    Key points:
    1. Use the specific URLs or construct the URL patterns you want to match using wildcard `*` and token characters `./`.
    2. In the host component and path component don't enter consecutive wildcard `*` for example: `example.*.*.com`.
    3. To match the exact domain and its subdirectories add a trailing slash `/` to your entry.
    4. The firewall interprets entries that do not end in a `/` or `*` with an implicit asterisk `*` to their end, which further increases the potential matches.
    5. The Use of multiple wildcards in a single pattern can impact the performance of the firewall.

    Domain/subdomains match examples:
    1. `*.example.com.*` will match `sub1.sub2.example.com.info.us` and `sub1.example.com.us` and `sub1.example.com/subdirectory` but not match `sub1.example.com`.
    2. `*.example.com` will match `sub1.example.com` and `sub1.sub2.example.com` and `sub1.example.com.au` but not match `example.com`.
    3. `*.example.com/` will match `sub1.sub2.example.com` and `sub1.example.com` but not match `sub1.example.com.au`.
    4. `example.com` will match `example.com` and `example.com.au` and `example.com.info.us` and `example.com/subdirectory`.
    5. `example.com/` will match `example.com` and `example.com/foo` but not `example.com.info.us`.
    6. `example.*.com` will match `example.sub1.com` and `example.sub1.sub2.com` and `example.sub1.com.au` and `example.sub1.com/subdirecroty`.
    7. `example.*.com/` will match `example.sub1.com` and `example.sub1.sub2.com` and `example.sub1.com/subdirecroty` but not match `example.sub1.com.au`.
    8. `example.com.*` will match `example.com.us` and `example.com.info.us` and `example.com.us/subdirectory` but not match `sub1.example.com`.

    Subdirectory or path match examples:
    1. `example.com/*` will match `example.com/foo` and `example.com/bar` and any `example.com/subdirectory`.
    2. `example.com/foo` will match `example.com/foo`.
    3. `www.example.com/foo/*` will match `www.exampe.com/foo/subdiectory`, but not match `www.example.com/FOO` or `www.example.com/bar/subdirectory`.
    4. `*.example.com/foo/*` will match `sub2.sub.example.com/foo/subdirectory` but not match `sub1.example.com/FOO` or `sub1.example.com/bar/subdirectory`.

    Other examples containing IP addresses in urls:
    1. 103.12.14.122/ will match 103.12.14.122 and 103.12.14.122/subdirectory.
    2. 103.12.14.122:8081/ will match 103.12.14.122:8081 and 103.12.14.122:8081/subdirectory.
    3. 2607:9d80:4680:3f01:0000:0000:00d0:00c0/ will match 2607:9d80:4680:3f01:0000:0000:00d0:00c0 and 2607:9d80:4680:3f01:0000:0000:00d0:00c0/subdirecroty.
    4. [2607:9d80:4680:3f01:0000:0000:00d0:00c0]:8081/ will match [2607:9d80:4680:3f01:0000:0000:00d0:00c0]:8081 and [2607:9d80:4680:3f01:0000:0000:00d0:00c0]:8081/subdirecroty.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SimpleUrlPattern object with values from keyword arguments. The default value of the :py:attr:`~oci.network_firewall.models.SimpleUrlPattern.type` attribute
        of this class is ``SIMPLE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this SimpleUrlPattern.
            Allowed values for this property are: "SIMPLE"
        :type type: str

        :param pattern:
            The value to assign to the pattern property of this SimpleUrlPattern.
        :type pattern: str

        """
        self.swagger_types = {
            'type': 'str',
            'pattern': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'pattern': 'pattern'
        }

        self._type = None
        self._pattern = None
        self._type = 'SIMPLE'

    @property
    def pattern(self):
        """
        **[Required]** Gets the pattern of this SimpleUrlPattern.
        A string consisting of a concatenation of optional host component and optional path component.
        The host component may start with `*.` to match the case-insensitive domain and all its subdomains.
        The path component must start with a `/`, and may end with `*` to match all paths of which it is a case-sensitive prefix.
        A missing host component matches all request domains, and a missing path component matches all request paths.
        An empty value matches all requests.


        :return: The pattern of this SimpleUrlPattern.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this SimpleUrlPattern.
        A string consisting of a concatenation of optional host component and optional path component.
        The host component may start with `*.` to match the case-insensitive domain and all its subdomains.
        The path component must start with a `/`, and may end with `*` to match all paths of which it is a case-sensitive prefix.
        A missing host component matches all request domains, and a missing path component matches all request paths.
        An empty value matches all requests.


        :param pattern: The pattern of this SimpleUrlPattern.
        :type: str
        """
        self._pattern = pattern

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceProfile(object):
    """
    Resource profile details
    """

    #: A constant which can be used with the risk_level property of a ResourceProfile.
    #: This constant has a value of "CRITICAL"
    RISK_LEVEL_CRITICAL = "CRITICAL"

    #: A constant which can be used with the risk_level property of a ResourceProfile.
    #: This constant has a value of "HIGH"
    RISK_LEVEL_HIGH = "HIGH"

    #: A constant which can be used with the risk_level property of a ResourceProfile.
    #: This constant has a value of "MEDIUM"
    RISK_LEVEL_MEDIUM = "MEDIUM"

    #: A constant which can be used with the risk_level property of a ResourceProfile.
    #: This constant has a value of "LOW"
    RISK_LEVEL_LOW = "LOW"

    #: A constant which can be used with the risk_level property of a ResourceProfile.
    #: This constant has a value of "MINOR"
    RISK_LEVEL_MINOR = "MINOR"

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceProfile object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sightings_count:
            The value to assign to the sightings_count property of this ResourceProfile.
        :type sightings_count: int

        :param id:
            The value to assign to the id property of this ResourceProfile.
        :type id: str

        :param resource_id:
            The value to assign to the resource_id property of this ResourceProfile.
        :type resource_id: str

        :param display_name:
            The value to assign to the display_name property of this ResourceProfile.
        :type display_name: str

        :param type:
            The value to assign to the type property of this ResourceProfile.
        :type type: str

        :param problem_ids:
            The value to assign to the problem_ids property of this ResourceProfile.
        :type problem_ids: list[str]

        :param compartment_id:
            The value to assign to the compartment_id property of this ResourceProfile.
        :type compartment_id: str

        :param target_id:
            The value to assign to the target_id property of this ResourceProfile.
        :type target_id: str

        :param risk_score:
            The value to assign to the risk_score property of this ResourceProfile.
        :type risk_score: float

        :param risk_level:
            The value to assign to the risk_level property of this ResourceProfile.
            Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type risk_level: str

        :param peak_risk_score:
            The value to assign to the peak_risk_score property of this ResourceProfile.
        :type peak_risk_score: float

        :param time_peak_score:
            The value to assign to the time_peak_score property of this ResourceProfile.
        :type time_peak_score: datetime

        :param time_first_detected:
            The value to assign to the time_first_detected property of this ResourceProfile.
        :type time_first_detected: datetime

        :param time_last_detected:
            The value to assign to the time_last_detected property of this ResourceProfile.
        :type time_last_detected: datetime

        :param tactics:
            The value to assign to the tactics property of this ResourceProfile.
        :type tactics: list[oci.cloud_guard.models.TacticSummary]

        """
        self.swagger_types = {
            'sightings_count': 'int',
            'id': 'str',
            'resource_id': 'str',
            'display_name': 'str',
            'type': 'str',
            'problem_ids': 'list[str]',
            'compartment_id': 'str',
            'target_id': 'str',
            'risk_score': 'float',
            'risk_level': 'str',
            'peak_risk_score': 'float',
            'time_peak_score': 'datetime',
            'time_first_detected': 'datetime',
            'time_last_detected': 'datetime',
            'tactics': 'list[TacticSummary]'
        }

        self.attribute_map = {
            'sightings_count': 'sightingsCount',
            'id': 'id',
            'resource_id': 'resourceId',
            'display_name': 'displayName',
            'type': 'type',
            'problem_ids': 'problemIds',
            'compartment_id': 'compartmentId',
            'target_id': 'targetId',
            'risk_score': 'riskScore',
            'risk_level': 'riskLevel',
            'peak_risk_score': 'peakRiskScore',
            'time_peak_score': 'timePeakScore',
            'time_first_detected': 'timeFirstDetected',
            'time_last_detected': 'timeLastDetected',
            'tactics': 'tactics'
        }

        self._sightings_count = None
        self._id = None
        self._resource_id = None
        self._display_name = None
        self._type = None
        self._problem_ids = None
        self._compartment_id = None
        self._target_id = None
        self._risk_score = None
        self._risk_level = None
        self._peak_risk_score = None
        self._time_peak_score = None
        self._time_first_detected = None
        self._time_last_detected = None
        self._tactics = None

    @property
    def sightings_count(self):
        """
        Gets the sightings_count of this ResourceProfile.
        Number of sightings associated with this resource profile


        :return: The sightings_count of this ResourceProfile.
        :rtype: int
        """
        return self._sightings_count

    @sightings_count.setter
    def sightings_count(self, sightings_count):
        """
        Sets the sightings_count of this ResourceProfile.
        Number of sightings associated with this resource profile


        :param sightings_count: The sightings_count of this ResourceProfile.
        :type: int
        """
        self._sightings_count = sightings_count

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ResourceProfile.
        Unique identifier for resource profile


        :return: The id of this ResourceProfile.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResourceProfile.
        Unique identifier for resource profile


        :param id: The id of this ResourceProfile.
        :type: str
        """
        self._id = id

    @property
    def resource_id(self):
        """
        **[Required]** Gets the resource_id of this ResourceProfile.
        Unique identifier for resource profile


        :return: The resource_id of this ResourceProfile.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this ResourceProfile.
        Unique identifier for resource profile


        :param resource_id: The resource_id of this ResourceProfile.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ResourceProfile.
        Resource name for resource profile


        :return: The display_name of this ResourceProfile.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ResourceProfile.
        Resource name for resource profile


        :param display_name: The display_name of this ResourceProfile.
        :type: str
        """
        self._display_name = display_name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this ResourceProfile.
        Resource type for resource profile


        :return: The type of this ResourceProfile.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ResourceProfile.
        Resource type for resource profile


        :param type: The type of this ResourceProfile.
        :type: str
        """
        self._type = type

    @property
    def problem_ids(self):
        """
        Gets the problem_ids of this ResourceProfile.
        List of Problems associated with the resource profile.


        :return: The problem_ids of this ResourceProfile.
        :rtype: list[str]
        """
        return self._problem_ids

    @problem_ids.setter
    def problem_ids(self, problem_ids):
        """
        Sets the problem_ids of this ResourceProfile.
        List of Problems associated with the resource profile.


        :param problem_ids: The problem_ids of this ResourceProfile.
        :type: list[str]
        """
        self._problem_ids = problem_ids

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ResourceProfile.
        Compartment Id for resource profile


        :return: The compartment_id of this ResourceProfile.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ResourceProfile.
        Compartment Id for resource profile


        :param compartment_id: The compartment_id of this ResourceProfile.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def target_id(self):
        """
        Gets the target_id of this ResourceProfile.
        Target Id for resource profile


        :return: The target_id of this ResourceProfile.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this ResourceProfile.
        Target Id for resource profile


        :param target_id: The target_id of this ResourceProfile.
        :type: str
        """
        self._target_id = target_id

    @property
    def risk_score(self):
        """
        **[Required]** Gets the risk_score of this ResourceProfile.
        Risk Score for the resource profile


        :return: The risk_score of this ResourceProfile.
        :rtype: float
        """
        return self._risk_score

    @risk_score.setter
    def risk_score(self, risk_score):
        """
        Sets the risk_score of this ResourceProfile.
        Risk Score for the resource profile


        :param risk_score: The risk_score of this ResourceProfile.
        :type: float
        """
        self._risk_score = risk_score

    @property
    def risk_level(self):
        """
        Gets the risk_level of this ResourceProfile.
        Risk Level associated with resource profile

        Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The risk_level of this ResourceProfile.
        :rtype: str
        """
        return self._risk_level

    @risk_level.setter
    def risk_level(self, risk_level):
        """
        Sets the risk_level of this ResourceProfile.
        Risk Level associated with resource profile


        :param risk_level: The risk_level of this ResourceProfile.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(risk_level, allowed_values):
            risk_level = 'UNKNOWN_ENUM_VALUE'
        self._risk_level = risk_level

    @property
    def peak_risk_score(self):
        """
        Gets the peak_risk_score of this ResourceProfile.
        Peak Risk Score for the resource profile


        :return: The peak_risk_score of this ResourceProfile.
        :rtype: float
        """
        return self._peak_risk_score

    @peak_risk_score.setter
    def peak_risk_score(self, peak_risk_score):
        """
        Sets the peak_risk_score of this ResourceProfile.
        Peak Risk Score for the resource profile


        :param peak_risk_score: The peak_risk_score of this ResourceProfile.
        :type: float
        """
        self._peak_risk_score = peak_risk_score

    @property
    def time_peak_score(self):
        """
        Gets the time_peak_score of this ResourceProfile.
        The date and time for peak risk score. Format defined by RFC3339.


        :return: The time_peak_score of this ResourceProfile.
        :rtype: datetime
        """
        return self._time_peak_score

    @time_peak_score.setter
    def time_peak_score(self, time_peak_score):
        """
        Sets the time_peak_score of this ResourceProfile.
        The date and time for peak risk score. Format defined by RFC3339.


        :param time_peak_score: The time_peak_score of this ResourceProfile.
        :type: datetime
        """
        self._time_peak_score = time_peak_score

    @property
    def time_first_detected(self):
        """
        **[Required]** Gets the time_first_detected of this ResourceProfile.
        The date and time the resource profile was first detected. Format defined by RFC3339.


        :return: The time_first_detected of this ResourceProfile.
        :rtype: datetime
        """
        return self._time_first_detected

    @time_first_detected.setter
    def time_first_detected(self, time_first_detected):
        """
        Sets the time_first_detected of this ResourceProfile.
        The date and time the resource profile was first detected. Format defined by RFC3339.


        :param time_first_detected: The time_first_detected of this ResourceProfile.
        :type: datetime
        """
        self._time_first_detected = time_first_detected

    @property
    def time_last_detected(self):
        """
        **[Required]** Gets the time_last_detected of this ResourceProfile.
        The date and time the resource profile was last detected. Format defined by RFC3339.


        :return: The time_last_detected of this ResourceProfile.
        :rtype: datetime
        """
        return self._time_last_detected

    @time_last_detected.setter
    def time_last_detected(self, time_last_detected):
        """
        Sets the time_last_detected of this ResourceProfile.
        The date and time the resource profile was last detected. Format defined by RFC3339.


        :param time_last_detected: The time_last_detected of this ResourceProfile.
        :type: datetime
        """
        self._time_last_detected = time_last_detected

    @property
    def tactics(self):
        """
        **[Required]** Gets the tactics of this ResourceProfile.
        List of tactic summary associated with the resource profile.


        :return: The tactics of this ResourceProfile.
        :rtype: list[oci.cloud_guard.models.TacticSummary]
        """
        return self._tactics

    @tactics.setter
    def tactics(self, tactics):
        """
        Sets the tactics of this ResourceProfile.
        List of tactic summary associated with the resource profile.


        :param tactics: The tactics of this ResourceProfile.
        :type: list[oci.cloud_guard.models.TacticSummary]
        """
        self._tactics = tactics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_selected import TargetSelected
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TargetResourceTypesSelected(TargetSelected):
    """
    Target selection on basis of TargetResourceTypes.
    """

    #: A constant which can be used with the values property of a TargetResourceTypesSelected.
    #: This constant has a value of "COMPARTMENT"
    VALUES_COMPARTMENT = "COMPARTMENT"

    #: A constant which can be used with the values property of a TargetResourceTypesSelected.
    #: This constant has a value of "ERPCLOUD"
    VALUES_ERPCLOUD = "ERPCLOUD"

    #: A constant which can be used with the values property of a TargetResourceTypesSelected.
    #: This constant has a value of "HCMCLOUD"
    VALUES_HCMCLOUD = "HCMCLOUD"

    #: A constant which can be used with the values property of a TargetResourceTypesSelected.
    #: This constant has a value of "SECURITY_ZONE"
    VALUES_SECURITY_ZONE = "SECURITY_ZONE"

    def __init__(self, **kwargs):
        """
        Initializes a new TargetResourceTypesSelected object with values from keyword arguments. The default value of the :py:attr:`~oci.cloud_guard.models.TargetResourceTypesSelected.kind` attribute
        of this class is ``TARGETTYPES`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this TargetResourceTypesSelected.
            Allowed values for this property are: "ALL", "TARGETTYPES", "TARGETIDS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type kind: str

        :param values:
            The value to assign to the values property of this TargetResourceTypesSelected.
            Allowed values for items in this list are: "COMPARTMENT", "ERPCLOUD", "HCMCLOUD", "SECURITY_ZONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type values: list[str]

        """
        self.swagger_types = {
            'kind': 'str',
            'values': 'list[str]'
        }

        self.attribute_map = {
            'kind': 'kind',
            'values': 'values'
        }

        self._kind = None
        self._values = None
        self._kind = 'TARGETTYPES'

    @property
    def values(self):
        """
        Gets the values of this TargetResourceTypesSelected.
        Types of Targets

        Allowed values for items in this list are: "COMPARTMENT", "ERPCLOUD", "HCMCLOUD", "SECURITY_ZONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The values of this TargetResourceTypesSelected.
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this TargetResourceTypesSelected.
        Types of Targets


        :param values: The values of this TargetResourceTypesSelected.
        :type: list[str]
        """
        allowed_values = ["COMPARTMENT", "ERPCLOUD", "HCMCLOUD", "SECURITY_ZONE"]
        if values:
            values[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in values]
        self._values = values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgRouteDistributionMatchCriteria(object):
    """
    The match criteria in a route distribution statement. The match criteria outlines which routes
    should be imported or exported.
    """

    #: A constant which can be used with the match_type property of a DrgRouteDistributionMatchCriteria.
    #: This constant has a value of "DRG_ATTACHMENT_TYPE"
    MATCH_TYPE_DRG_ATTACHMENT_TYPE = "DRG_ATTACHMENT_TYPE"

    #: A constant which can be used with the match_type property of a DrgRouteDistributionMatchCriteria.
    #: This constant has a value of "DRG_ATTACHMENT_ID"
    MATCH_TYPE_DRG_ATTACHMENT_ID = "DRG_ATTACHMENT_ID"

    def __init__(self, **kwargs):
        """
        Initializes a new DrgRouteDistributionMatchCriteria object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.vn_monitoring.models.DrgAttachmentIdDrgRouteDistributionMatchCriteria`
        * :class:`~oci.vn_monitoring.models.DrgAttachmentTypeDrgRouteDistributionMatchCriteria`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param match_type:
            The value to assign to the match_type property of this DrgRouteDistributionMatchCriteria.
            Allowed values for this property are: "DRG_ATTACHMENT_TYPE", "DRG_ATTACHMENT_ID"
        :type match_type: str

        """
        self.swagger_types = {
            'match_type': 'str'
        }

        self.attribute_map = {
            'match_type': 'matchType'
        }

        self._match_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['matchType']

        if type == 'DRG_ATTACHMENT_ID':
            return 'DrgAttachmentIdDrgRouteDistributionMatchCriteria'

        if type == 'DRG_ATTACHMENT_TYPE':
            return 'DrgAttachmentTypeDrgRouteDistributionMatchCriteria'
        else:
            return 'DrgRouteDistributionMatchCriteria'

    @property
    def match_type(self):
        """
        **[Required]** Gets the match_type of this DrgRouteDistributionMatchCriteria.
        The type of the match criteria for a route distribution statement.

        Allowed values for this property are: "DRG_ATTACHMENT_TYPE", "DRG_ATTACHMENT_ID"


        :return: The match_type of this DrgRouteDistributionMatchCriteria.
        :rtype: str
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """
        Sets the match_type of this DrgRouteDistributionMatchCriteria.
        The type of the match criteria for a route distribution statement.


        :param match_type: The match_type of this DrgRouteDistributionMatchCriteria.
        :type: str
        """
        allowed_values = ["DRG_ATTACHMENT_TYPE", "DRG_ATTACHMENT_ID"]
        if not value_allowed_none_or_none_sentinel(match_type, allowed_values):
            raise ValueError(
                "Invalid value for `match_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._match_type = match_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .endpoint import Endpoint
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceEndpoint(Endpoint):
    """
    Defines the details required for a COMPUTE_INSTANCE-type `Endpoint`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceEndpoint object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.ComputeInstanceEndpoint.type` attribute
        of this class is ``COMPUTE_INSTANCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ComputeInstanceEndpoint.
            Allowed values for this property are: "IP_ADDRESS", "SUBNET", "COMPUTE_INSTANCE", "VNIC", "LOAD_BALANCER", "LOAD_BALANCER_LISTENER", "NETWORK_LOAD_BALANCER", "NETWORK_LOAD_BALANCER_LISTENER", "VLAN"
        :type type: str

        :param address:
            The value to assign to the address property of this ComputeInstanceEndpoint.
        :type address: str

        :param instance_id:
            The value to assign to the instance_id property of this ComputeInstanceEndpoint.
        :type instance_id: str

        :param vnic_id:
            The value to assign to the vnic_id property of this ComputeInstanceEndpoint.
        :type vnic_id: str

        """
        self.swagger_types = {
            'type': 'str',
            'address': 'str',
            'instance_id': 'str',
            'vnic_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'address': 'address',
            'instance_id': 'instanceId',
            'vnic_id': 'vnicId'
        }

        self._type = None
        self._address = None
        self._instance_id = None
        self._vnic_id = None
        self._type = 'COMPUTE_INSTANCE'

    @property
    def address(self):
        """
        **[Required]** Gets the address of this ComputeInstanceEndpoint.
        The IPv4 address of the COMPUTE_INSTANCE-type `Endpoint` object.


        :return: The address of this ComputeInstanceEndpoint.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ComputeInstanceEndpoint.
        The IPv4 address of the COMPUTE_INSTANCE-type `Endpoint` object.


        :param address: The address of this ComputeInstanceEndpoint.
        :type: str
        """
        self._address = address

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this ComputeInstanceEndpoint.
        The `OCID`__ of the compute instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The instance_id of this ComputeInstanceEndpoint.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this ComputeInstanceEndpoint.
        The `OCID`__ of the compute instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param instance_id: The instance_id of this ComputeInstanceEndpoint.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def vnic_id(self):
        """
        **[Required]** Gets the vnic_id of this ComputeInstanceEndpoint.
        The `OCID`__ of the VNIC attached to the compute instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vnic_id of this ComputeInstanceEndpoint.
        :rtype: str
        """
        return self._vnic_id

    @vnic_id.setter
    def vnic_id(self, vnic_id):
        """
        Sets the vnic_id of this ComputeInstanceEndpoint.
        The `OCID`__ of the VNIC attached to the compute instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vnic_id: The vnic_id of this ComputeInstanceEndpoint.
        :type: str
        """
        self._vnic_id = vnic_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IngressGatewayHost(object):
    """
    Host for the ingress listener.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new IngressGatewayHost object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this IngressGatewayHost.
        :type name: str

        :param hostnames:
            The value to assign to the hostnames property of this IngressGatewayHost.
        :type hostnames: list[str]

        :param listeners:
            The value to assign to the listeners property of this IngressGatewayHost.
        :type listeners: list[oci.service_mesh.models.IngressGatewayListener]

        """
        self.swagger_types = {
            'name': 'str',
            'hostnames': 'list[str]',
            'listeners': 'list[IngressGatewayListener]'
        }

        self.attribute_map = {
            'name': 'name',
            'hostnames': 'hostnames',
            'listeners': 'listeners'
        }

        self._name = None
        self._hostnames = None
        self._listeners = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this IngressGatewayHost.
        A user-friendly name for the host. The name must be unique within the same ingress gateway.
        This name can be used in the ingress gateway route table resource to attach a route to this host.

        Example: `MyExampleHost`


        :return: The name of this IngressGatewayHost.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IngressGatewayHost.
        A user-friendly name for the host. The name must be unique within the same ingress gateway.
        This name can be used in the ingress gateway route table resource to attach a route to this host.

        Example: `MyExampleHost`


        :param name: The name of this IngressGatewayHost.
        :type: str
        """
        self._name = name

    @property
    def hostnames(self):
        """
        Gets the hostnames of this IngressGatewayHost.
        Hostnames of the host. Applicable only for HTTP and TLS_PASSTHROUGH listeners.
        Wildcard hostnames are supported in the prefix form.
        Examples of valid hostnames are \"www.example.com\", \"*.example.com\", \"*.com\".


        :return: The hostnames of this IngressGatewayHost.
        :rtype: list[str]
        """
        return self._hostnames

    @hostnames.setter
    def hostnames(self, hostnames):
        """
        Sets the hostnames of this IngressGatewayHost.
        Hostnames of the host. Applicable only for HTTP and TLS_PASSTHROUGH listeners.
        Wildcard hostnames are supported in the prefix form.
        Examples of valid hostnames are \"www.example.com\", \"*.example.com\", \"*.com\".


        :param hostnames: The hostnames of this IngressGatewayHost.
        :type: list[str]
        """
        self._hostnames = hostnames

    @property
    def listeners(self):
        """
        **[Required]** Gets the listeners of this IngressGatewayHost.
        The listeners for the ingress gateway.


        :return: The listeners of this IngressGatewayHost.
        :rtype: list[oci.service_mesh.models.IngressGatewayListener]
        """
        return self._listeners

    @listeners.setter
    def listeners(self, listeners):
        """
        Sets the listeners of this IngressGatewayHost.
        The listeners for the ingress gateway.


        :param listeners: The listeners of this IngressGatewayHost.
        :type: list[oci.service_mesh.models.IngressGatewayListener]
        """
        self._listeners = listeners

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDrgRouteDistributionStatementDetails(object):
    """
    Route distribution statements to update in the route distribution.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDrgRouteDistributionStatementDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this UpdateDrgRouteDistributionStatementDetails.
        :type id: str

        :param match_criteria:
            The value to assign to the match_criteria property of this UpdateDrgRouteDistributionStatementDetails.
        :type match_criteria: list[oci.vn_monitoring.models.DrgRouteDistributionMatchCriteria]

        :param priority:
            The value to assign to the priority property of this UpdateDrgRouteDistributionStatementDetails.
        :type priority: int

        """
        self.swagger_types = {
            'id': 'str',
            'match_criteria': 'list[DrgRouteDistributionMatchCriteria]',
            'priority': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'match_criteria': 'matchCriteria',
            'priority': 'priority'
        }

        self._id = None
        self._match_criteria = None
        self._priority = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this UpdateDrgRouteDistributionStatementDetails.
        The Oracle-assigned ID of each route distribution statement to be updated.


        :return: The id of this UpdateDrgRouteDistributionStatementDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UpdateDrgRouteDistributionStatementDetails.
        The Oracle-assigned ID of each route distribution statement to be updated.


        :param id: The id of this UpdateDrgRouteDistributionStatementDetails.
        :type: str
        """
        self._id = id

    @property
    def match_criteria(self):
        """
        Gets the match_criteria of this UpdateDrgRouteDistributionStatementDetails.
        The action is applied only if all of the match criteria is met.


        :return: The match_criteria of this UpdateDrgRouteDistributionStatementDetails.
        :rtype: list[oci.vn_monitoring.models.DrgRouteDistributionMatchCriteria]
        """
        return self._match_criteria

    @match_criteria.setter
    def match_criteria(self, match_criteria):
        """
        Sets the match_criteria of this UpdateDrgRouteDistributionStatementDetails.
        The action is applied only if all of the match criteria is met.


        :param match_criteria: The match_criteria of this UpdateDrgRouteDistributionStatementDetails.
        :type: list[oci.vn_monitoring.models.DrgRouteDistributionMatchCriteria]
        """
        self._match_criteria = match_criteria

    @property
    def priority(self):
        """
        Gets the priority of this UpdateDrgRouteDistributionStatementDetails.
        The priority of the statement you'd like to update.


        :return: The priority of this UpdateDrgRouteDistributionStatementDetails.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this UpdateDrgRouteDistributionStatementDetails.
        The priority of the statement you'd like to update.


        :param priority: The priority of this UpdateDrgRouteDistributionStatementDetails.
        :type: int
        """
        self._priority = priority

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .format_entry import FormatEntry
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SQLExpressionFormatEntry(FormatEntry):
    """
    The SQL Expression masking format uses a SQL expression to generate values
    that are used to replace the original data values. SQL expressions with
    dbms_lob and other user-defined functions can be used to mask columns of
    Large Object data type (LOB). To learn more, check SQL Expression in the
    Data Safe documentation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SQLExpressionFormatEntry object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.SQLExpressionFormatEntry.type` attribute
        of this class is ``SQL_EXPRESSION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this SQLExpressionFormatEntry.
            Allowed values for this property are: "DELETE_ROWS", "DETERMINISTIC_SUBSTITUTION", "DETERMINISTIC_ENCRYPTION", "DETERMINISTIC_ENCRYPTION_DATE", "FIXED_NUMBER", "FIXED_STRING", "LIBRARY_MASKING_FORMAT", "NULL_VALUE", "POST_PROCESSING_FUNCTION", "PRESERVE_ORIGINAL_DATA", "RANDOM_DATE", "RANDOM_DECIMAL_NUMBER", "RANDOM_DIGITS", "RANDOM_LIST", "RANDOM_NUMBER", "RANDOM_STRING", "RANDOM_SUBSTITUTION", "REGULAR_EXPRESSION", "SHUFFLE", "SQL_EXPRESSION", "SUBSTRING", "TRUNCATE_TABLE", "USER_DEFINED_FUNCTION"
        :type type: str

        :param description:
            The value to assign to the description property of this SQLExpressionFormatEntry.
        :type description: str

        :param sql_expression:
            The value to assign to the sql_expression property of this SQLExpressionFormatEntry.
        :type sql_expression: str

        """
        self.swagger_types = {
            'type': 'str',
            'description': 'str',
            'sql_expression': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'description': 'description',
            'sql_expression': 'sqlExpression'
        }

        self._type = None
        self._description = None
        self._sql_expression = None
        self._type = 'SQL_EXPRESSION'

    @property
    def sql_expression(self):
        """
        **[Required]** Gets the sql_expression of this SQLExpressionFormatEntry.
        The SQL expression to be used to generate the masked values. It can
        consist of one or more values, operators, and SQL functions that
        evaluate to a value. It can also contain substitution columns from
        the same table. Specify the substitution columns within percent (%)
        symbols.


        :return: The sql_expression of this SQLExpressionFormatEntry.
        :rtype: str
        """
        return self._sql_expression

    @sql_expression.setter
    def sql_expression(self, sql_expression):
        """
        Sets the sql_expression of this SQLExpressionFormatEntry.
        The SQL expression to be used to generate the masked values. It can
        consist of one or more values, operators, and SQL functions that
        evaluate to a value. It can also contain substitution columns from
        the same table. Specify the substitution columns within percent (%)
        symbols.


        :param sql_expression: The sql_expression of this SQLExpressionFormatEntry.
        :type: str
        """
        self._sql_expression = sql_expression

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TrafficRoute(object):
    """
    Defines the traffic route taken in the path in `PathAnalysisResult`.
    """

    #: A constant which can be used with the reachability_status property of a TrafficRoute.
    #: This constant has a value of "REACHABLE"
    REACHABILITY_STATUS_REACHABLE = "REACHABLE"

    #: A constant which can be used with the reachability_status property of a TrafficRoute.
    #: This constant has a value of "UNREACHABLE"
    REACHABILITY_STATUS_UNREACHABLE = "UNREACHABLE"

    #: A constant which can be used with the reachability_status property of a TrafficRoute.
    #: This constant has a value of "INDETERMINATE"
    REACHABILITY_STATUS_INDETERMINATE = "INDETERMINATE"

    def __init__(self, **kwargs):
        """
        Initializes a new TrafficRoute object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param reachability_status:
            The value to assign to the reachability_status property of this TrafficRoute.
            Allowed values for this property are: "REACHABLE", "UNREACHABLE", "INDETERMINATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type reachability_status: str

        :param nodes:
            The value to assign to the nodes property of this TrafficRoute.
        :type nodes: list[oci.vn_monitoring.models.TrafficNode]

        :param route_analysis_description:
            The value to assign to the route_analysis_description property of this TrafficRoute.
        :type route_analysis_description: str

        """
        self.swagger_types = {
            'reachability_status': 'str',
            'nodes': 'list[TrafficNode]',
            'route_analysis_description': 'str'
        }

        self.attribute_map = {
            'reachability_status': 'reachabilityStatus',
            'nodes': 'nodes',
            'route_analysis_description': 'routeAnalysisDescription'
        }

        self._reachability_status = None
        self._nodes = None
        self._route_analysis_description = None

    @property
    def reachability_status(self):
        """
        **[Required]** Gets the reachability_status of this TrafficRoute.
        Reachability status for the given traffic route.

        Allowed values for this property are: "REACHABLE", "UNREACHABLE", "INDETERMINATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The reachability_status of this TrafficRoute.
        :rtype: str
        """
        return self._reachability_status

    @reachability_status.setter
    def reachability_status(self, reachability_status):
        """
        Sets the reachability_status of this TrafficRoute.
        Reachability status for the given traffic route.


        :param reachability_status: The reachability_status of this TrafficRoute.
        :type: str
        """
        allowed_values = ["REACHABLE", "UNREACHABLE", "INDETERMINATE"]
        if not value_allowed_none_or_none_sentinel(reachability_status, allowed_values):
            reachability_status = 'UNKNOWN_ENUM_VALUE'
        self._reachability_status = reachability_status

    @property
    def nodes(self):
        """
        **[Required]** Gets the nodes of this TrafficRoute.
        The ordered sequence of nodes in the given the traffic route forming a path.


        :return: The nodes of this TrafficRoute.
        :rtype: list[oci.vn_monitoring.models.TrafficNode]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """
        Sets the nodes of this TrafficRoute.
        The ordered sequence of nodes in the given the traffic route forming a path.


        :param nodes: The nodes of this TrafficRoute.
        :type: list[oci.vn_monitoring.models.TrafficNode]
        """
        self._nodes = nodes

    @property
    def route_analysis_description(self):
        """
        Gets the route_analysis_description of this TrafficRoute.
        A description of the traffic route analysis. For example: \"Traffic might not reach a destination
        due to the LB backend being unhealthy\".


        :return: The route_analysis_description of this TrafficRoute.
        :rtype: str
        """
        return self._route_analysis_description

    @route_analysis_description.setter
    def route_analysis_description(self, route_analysis_description):
        """
        Sets the route_analysis_description of this TrafficRoute.
        A description of the traffic route analysis. For example: \"Traffic might not reach a destination
        due to the LB backend being unhealthy\".


        :param route_analysis_description: The route_analysis_description of this TrafficRoute.
        :type: str
        """
        self._route_analysis_description = route_analysis_description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Channel(object):
    """
    Properties of a Channel.
    """

    #: A constant which can be used with the category property of a Channel.
    #: This constant has a value of "AGENT"
    CATEGORY_AGENT = "AGENT"

    #: A constant which can be used with the category property of a Channel.
    #: This constant has a value of "APPLICATION"
    CATEGORY_APPLICATION = "APPLICATION"

    #: A constant which can be used with the category property of a Channel.
    #: This constant has a value of "BOT"
    CATEGORY_BOT = "BOT"

    #: A constant which can be used with the category property of a Channel.
    #: This constant has a value of "BOT_AS_AGENT"
    CATEGORY_BOT_AS_AGENT = "BOT_AS_AGENT"

    #: A constant which can be used with the category property of a Channel.
    #: This constant has a value of "SYSTEM"
    CATEGORY_SYSTEM = "SYSTEM"

    #: A constant which can be used with the category property of a Channel.
    #: This constant has a value of "EVENT"
    CATEGORY_EVENT = "EVENT"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "ANDROID"
    TYPE_ANDROID = "ANDROID"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "APPEVENT"
    TYPE_APPEVENT = "APPEVENT"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "APPLICATION"
    TYPE_APPLICATION = "APPLICATION"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "CORTANA"
    TYPE_CORTANA = "CORTANA"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "FACEBOOK"
    TYPE_FACEBOOK = "FACEBOOK"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "IOS"
    TYPE_IOS = "IOS"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "MSTEAMS"
    TYPE_MSTEAMS = "MSTEAMS"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "OSS"
    TYPE_OSS = "OSS"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "OSVC"
    TYPE_OSVC = "OSVC"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "SERVICECLOUD"
    TYPE_SERVICECLOUD = "SERVICECLOUD"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "SLACK"
    TYPE_SLACK = "SLACK"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "TEST"
    TYPE_TEST = "TEST"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "TWILIO"
    TYPE_TWILIO = "TWILIO"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "WEB"
    TYPE_WEB = "WEB"

    #: A constant which can be used with the type property of a Channel.
    #: This constant has a value of "WEBHOOK"
    TYPE_WEBHOOK = "WEBHOOK"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Channel.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Channel object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.oda.models.AppEventChannel`
        * :class:`~oci.oda.models.FacebookChannel`
        * :class:`~oci.oda.models.WebChannel`
        * :class:`~oci.oda.models.MSTeamsChannel`
        * :class:`~oci.oda.models.TwilioChannel`
        * :class:`~oci.oda.models.OsvcChannel`
        * :class:`~oci.oda.models.AndroidChannel`
        * :class:`~oci.oda.models.OSSChannel`
        * :class:`~oci.oda.models.WebhookChannel`
        * :class:`~oci.oda.models.ApplicationChannel`
        * :class:`~oci.oda.models.SlackChannel`
        * :class:`~oci.oda.models.CortanaChannel`
        * :class:`~oci.oda.models.ServiceCloudChannel`
        * :class:`~oci.oda.models.IosChannel`
        * :class:`~oci.oda.models.TestChannel`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Channel.
        :type id: str

        :param name:
            The value to assign to the name property of this Channel.
        :type name: str

        :param description:
            The value to assign to the description property of this Channel.
        :type description: str

        :param category:
            The value to assign to the category property of this Channel.
            Allowed values for this property are: "AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param type:
            The value to assign to the type property of this Channel.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this Channel.
        :type session_expiry_duration_in_milliseconds: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Channel.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this Channel.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Channel.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Channel.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Channel.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'category': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'category': 'category',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._name = None
        self._description = None
        self._category = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'APPEVENT':
            return 'AppEventChannel'

        if type == 'FACEBOOK':
            return 'FacebookChannel'

        if type == 'WEB':
            return 'WebChannel'

        if type == 'MSTEAMS':
            return 'MSTeamsChannel'

        if type == 'TWILIO':
            return 'TwilioChannel'

        if type == 'OSVC':
            return 'OsvcChannel'

        if type == 'ANDROID':
            return 'AndroidChannel'

        if type == 'OSS':
            return 'OSSChannel'

        if type == 'WEBHOOK':
            return 'WebhookChannel'

        if type == 'APPLICATION':
            return 'ApplicationChannel'

        if type == 'SLACK':
            return 'SlackChannel'

        if type == 'CORTANA':
            return 'CortanaChannel'

        if type == 'SERVICECLOUD':
            return 'ServiceCloudChannel'

        if type == 'IOS':
            return 'IosChannel'

        if type == 'TEST':
            return 'TestChannel'
        else:
            return 'Channel'

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Channel.
        Unique immutable identifier that was assigned when the Channel was created.


        :return: The id of this Channel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Channel.
        Unique immutable identifier that was assigned when the Channel was created.


        :param id: The id of this Channel.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Channel.
        The Channel's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.


        :return: The name of this Channel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Channel.
        The Channel's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.


        :param name: The name of this Channel.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Channel.
        A short description of the Channel.


        :return: The description of this Channel.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Channel.
        A short description of the Channel.


        :param description: The description of this Channel.
        :type: str
        """
        self._description = description

    @property
    def category(self):
        """
        **[Required]** Gets the category of this Channel.
        The category of the Channel.

        Allowed values for this property are: "AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The category of this Channel.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this Channel.
        The category of the Channel.


        :param category: The category of this Channel.
        :type: str
        """
        allowed_values = ["AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT"]
        if not value_allowed_none_or_none_sentinel(category, allowed_values):
            category = 'UNKNOWN_ENUM_VALUE'
        self._category = category

    @property
    def type(self):
        """
        **[Required]** Gets the type of this Channel.
        The Channel type.

        Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this Channel.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Channel.
        The Channel type.


        :param type: The type of this Channel.
        :type: str
        """
        allowed_values = ["ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def session_expiry_duration_in_milliseconds(self):
        """
        Gets the session_expiry_duration_in_milliseconds of this Channel.
        The number of milliseconds before a session expires.


        :return: The session_expiry_duration_in_milliseconds of this Channel.
        :rtype: int
        """
        return self._session_expiry_duration_in_milliseconds

    @session_expiry_duration_in_milliseconds.setter
    def session_expiry_duration_in_milliseconds(self, session_expiry_duration_in_milliseconds):
        """
        Sets the session_expiry_duration_in_milliseconds of this Channel.
        The number of milliseconds before a session expires.


        :param session_expiry_duration_in_milliseconds: The session_expiry_duration_in_milliseconds of this Channel.
        :type: int
        """
        self._session_expiry_duration_in_milliseconds = session_expiry_duration_in_milliseconds

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Channel.
        The Channel's current state.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Channel.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Channel.
        The Channel's current state.


        :param lifecycle_state: The lifecycle_state of this Channel.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Channel.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this Channel.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Channel.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this Channel.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this Channel.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this Channel.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Channel.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this Channel.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Channel.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Channel.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Channel.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Channel.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Channel.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Channel.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Channel.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Channel.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_details import TargetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecurityZoneTargetDetails(TargetDetails):
    """
    Details about Security Zone Target.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SecurityZoneTargetDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.cloud_guard.models.SecurityZoneTargetDetails.target_resource_type` attribute
        of this class is ``SECURITY_ZONE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target_resource_type:
            The value to assign to the target_resource_type property of this SecurityZoneTargetDetails.
            Allowed values for this property are: "COMPARTMENT", "ERPCLOUD", "HCMCLOUD", "SECURITY_ZONE"
        :type target_resource_type: str

        :param security_zone_id:
            The value to assign to the security_zone_id property of this SecurityZoneTargetDetails.
        :type security_zone_id: str

        :param security_zone_display_name:
            The value to assign to the security_zone_display_name property of this SecurityZoneTargetDetails.
        :type security_zone_display_name: str

        :param target_security_zone_recipes:
            The value to assign to the target_security_zone_recipes property of this SecurityZoneTargetDetails.
        :type target_security_zone_recipes: list[oci.cloud_guard.models.SecurityRecipe]

        """
        self.swagger_types = {
            'target_resource_type': 'str',
            'security_zone_id': 'str',
            'security_zone_display_name': 'str',
            'target_security_zone_recipes': 'list[SecurityRecipe]'
        }

        self.attribute_map = {
            'target_resource_type': 'targetResourceType',
            'security_zone_id': 'securityZoneId',
            'security_zone_display_name': 'securityZoneDisplayName',
            'target_security_zone_recipes': 'targetSecurityZoneRecipes'
        }

        self._target_resource_type = None
        self._security_zone_id = None
        self._security_zone_display_name = None
        self._target_security_zone_recipes = None
        self._target_resource_type = 'SECURITY_ZONE'

    @property
    def security_zone_id(self):
        """
        Gets the security_zone_id of this SecurityZoneTargetDetails.
        The OCID of the security zone to associate this compartment with.


        :return: The security_zone_id of this SecurityZoneTargetDetails.
        :rtype: str
        """
        return self._security_zone_id

    @security_zone_id.setter
    def security_zone_id(self, security_zone_id):
        """
        Sets the security_zone_id of this SecurityZoneTargetDetails.
        The OCID of the security zone to associate this compartment with.


        :param security_zone_id: The security_zone_id of this SecurityZoneTargetDetails.
        :type: str
        """
        self._security_zone_id = security_zone_id

    @property
    def security_zone_display_name(self):
        """
        Gets the security_zone_display_name of this SecurityZoneTargetDetails.
        The name of the security zone to associate this compartment with.


        :return: The security_zone_display_name of this SecurityZoneTargetDetails.
        :rtype: str
        """
        return self._security_zone_display_name

    @security_zone_display_name.setter
    def security_zone_display_name(self, security_zone_display_name):
        """
        Sets the security_zone_display_name of this SecurityZoneTargetDetails.
        The name of the security zone to associate this compartment with.


        :param security_zone_display_name: The security_zone_display_name of this SecurityZoneTargetDetails.
        :type: str
        """
        self._security_zone_display_name = security_zone_display_name

    @property
    def target_security_zone_recipes(self):
        """
        Gets the target_security_zone_recipes of this SecurityZoneTargetDetails.
        The list of security zone recipes to associate this compartment with.


        :return: The target_security_zone_recipes of this SecurityZoneTargetDetails.
        :rtype: list[oci.cloud_guard.models.SecurityRecipe]
        """
        return self._target_security_zone_recipes

    @target_security_zone_recipes.setter
    def target_security_zone_recipes(self, target_security_zone_recipes):
        """
        Sets the target_security_zone_recipes of this SecurityZoneTargetDetails.
        The list of security zone recipes to associate this compartment with.


        :param target_security_zone_recipes: The target_security_zone_recipes of this SecurityZoneTargetDetails.
        :type: list[oci.cloud_guard.models.SecurityRecipe]
        """
        self._target_security_zone_recipes = target_security_zone_recipes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseToolsKeyStoreMySqlSummary(object):
    """
    The key store secrets.
    """

    #: A constant which can be used with the key_store_type property of a DatabaseToolsKeyStoreMySqlSummary.
    #: This constant has a value of "CLIENT_CERTIFICATE_PEM"
    KEY_STORE_TYPE_CLIENT_CERTIFICATE_PEM = "CLIENT_CERTIFICATE_PEM"

    #: A constant which can be used with the key_store_type property of a DatabaseToolsKeyStoreMySqlSummary.
    #: This constant has a value of "CLIENT_PRIVATE_KEY_PEM"
    KEY_STORE_TYPE_CLIENT_PRIVATE_KEY_PEM = "CLIENT_PRIVATE_KEY_PEM"

    #: A constant which can be used with the key_store_type property of a DatabaseToolsKeyStoreMySqlSummary.
    #: This constant has a value of "CA_CERTIFICATE_PEM"
    KEY_STORE_TYPE_CA_CERTIFICATE_PEM = "CA_CERTIFICATE_PEM"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseToolsKeyStoreMySqlSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key_store_type:
            The value to assign to the key_store_type property of this DatabaseToolsKeyStoreMySqlSummary.
            Allowed values for this property are: "CLIENT_CERTIFICATE_PEM", "CLIENT_PRIVATE_KEY_PEM", "CA_CERTIFICATE_PEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type key_store_type: str

        :param key_store_content:
            The value to assign to the key_store_content property of this DatabaseToolsKeyStoreMySqlSummary.
        :type key_store_content: oci.database_tools.models.DatabaseToolsKeyStoreContentMySqlSummary

        :param key_store_password:
            The value to assign to the key_store_password property of this DatabaseToolsKeyStoreMySqlSummary.
        :type key_store_password: oci.database_tools.models.DatabaseToolsKeyStorePasswordMySqlSummary

        """
        self.swagger_types = {
            'key_store_type': 'str',
            'key_store_content': 'DatabaseToolsKeyStoreContentMySqlSummary',
            'key_store_password': 'DatabaseToolsKeyStorePasswordMySqlSummary'
        }

        self.attribute_map = {
            'key_store_type': 'keyStoreType',
            'key_store_content': 'keyStoreContent',
            'key_store_password': 'keyStorePassword'
        }

        self._key_store_type = None
        self._key_store_content = None
        self._key_store_password = None

    @property
    def key_store_type(self):
        """
        Gets the key_store_type of this DatabaseToolsKeyStoreMySqlSummary.
        The key store type.

        Allowed values for this property are: "CLIENT_CERTIFICATE_PEM", "CLIENT_PRIVATE_KEY_PEM", "CA_CERTIFICATE_PEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The key_store_type of this DatabaseToolsKeyStoreMySqlSummary.
        :rtype: str
        """
        return self._key_store_type

    @key_store_type.setter
    def key_store_type(self, key_store_type):
        """
        Sets the key_store_type of this DatabaseToolsKeyStoreMySqlSummary.
        The key store type.


        :param key_store_type: The key_store_type of this DatabaseToolsKeyStoreMySqlSummary.
        :type: str
        """
        allowed_values = ["CLIENT_CERTIFICATE_PEM", "CLIENT_PRIVATE_KEY_PEM", "CA_CERTIFICATE_PEM"]
        if not value_allowed_none_or_none_sentinel(key_store_type, allowed_values):
            key_store_type = 'UNKNOWN_ENUM_VALUE'
        self._key_store_type = key_store_type

    @property
    def key_store_content(self):
        """
        Gets the key_store_content of this DatabaseToolsKeyStoreMySqlSummary.

        :return: The key_store_content of this DatabaseToolsKeyStoreMySqlSummary.
        :rtype: oci.database_tools.models.DatabaseToolsKeyStoreContentMySqlSummary
        """
        return self._key_store_content

    @key_store_content.setter
    def key_store_content(self, key_store_content):
        """
        Sets the key_store_content of this DatabaseToolsKeyStoreMySqlSummary.

        :param key_store_content: The key_store_content of this DatabaseToolsKeyStoreMySqlSummary.
        :type: oci.database_tools.models.DatabaseToolsKeyStoreContentMySqlSummary
        """
        self._key_store_content = key_store_content

    @property
    def key_store_password(self):
        """
        Gets the key_store_password of this DatabaseToolsKeyStoreMySqlSummary.

        :return: The key_store_password of this DatabaseToolsKeyStoreMySqlSummary.
        :rtype: oci.database_tools.models.DatabaseToolsKeyStorePasswordMySqlSummary
        """
        return self._key_store_password

    @key_store_password.setter
    def key_store_password(self, key_store_password):
        """
        Sets the key_store_password of this DatabaseToolsKeyStoreMySqlSummary.

        :param key_store_password: The key_store_password of this DatabaseToolsKeyStoreMySqlSummary.
        :type: oci.database_tools.models.DatabaseToolsKeyStorePasswordMySqlSummary
        """
        self._key_store_password = key_store_password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DomainSummary(object):
    """
    (For tenancies that support identity domains) As the name suggests, a `DomainSummary` object contains information about a `Domain`.
    """

    #: A constant which can be used with the type property of a DomainSummary.
    #: This constant has a value of "DEFAULT"
    TYPE_DEFAULT = "DEFAULT"

    #: A constant which can be used with the type property of a DomainSummary.
    #: This constant has a value of "SECONDARY"
    TYPE_SECONDARY = "SECONDARY"

    #: A constant which can be used with the lifecycle_state property of a DomainSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DomainSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DomainSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DomainSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_details property of a DomainSummary.
    #: This constant has a value of "DEACTIVATING"
    LIFECYCLE_DETAILS_DEACTIVATING = "DEACTIVATING"

    #: A constant which can be used with the lifecycle_details property of a DomainSummary.
    #: This constant has a value of "ACTIVATING"
    LIFECYCLE_DETAILS_ACTIVATING = "ACTIVATING"

    #: A constant which can be used with the lifecycle_details property of a DomainSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_DETAILS_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new DomainSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DomainSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DomainSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this DomainSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DomainSummary.
        :type description: str

        :param url:
            The value to assign to the url property of this DomainSummary.
        :type url: str

        :param home_region_url:
            The value to assign to the home_region_url property of this DomainSummary.
        :type home_region_url: str

        :param home_region:
            The value to assign to the home_region property of this DomainSummary.
        :type home_region: str

        :param replica_regions:
            The value to assign to the replica_regions property of this DomainSummary.
        :type replica_regions: list[oci.identity.models.ReplicatedRegionDetails]

        :param type:
            The value to assign to the type property of this DomainSummary.
            Allowed values for this property are: "DEFAULT", "SECONDARY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param license_type:
            The value to assign to the license_type property of this DomainSummary.
        :type license_type: str

        :param is_hidden_on_login:
            The value to assign to the is_hidden_on_login property of this DomainSummary.
        :type is_hidden_on_login: bool

        :param time_created:
            The value to assign to the time_created property of this DomainSummary.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DomainSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DomainSummary.
            Allowed values for this property are: "DEACTIVATING", "ACTIVATING", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DomainSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DomainSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'url': 'str',
            'home_region_url': 'str',
            'home_region': 'str',
            'replica_regions': 'list[ReplicatedRegionDetails]',
            'type': 'str',
            'license_type': 'str',
            'is_hidden_on_login': 'bool',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'url': 'url',
            'home_region_url': 'homeRegionUrl',
            'home_region': 'homeRegion',
            'replica_regions': 'replicaRegions',
            'type': 'type',
            'license_type': 'licenseType',
            'is_hidden_on_login': 'isHiddenOnLogin',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._url = None
        self._home_region_url = None
        self._home_region = None
        self._replica_regions = None
        self._type = None
        self._license_type = None
        self._is_hidden_on_login = None
        self._time_created = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DomainSummary.
        The OCID of the identity domain.


        :return: The id of this DomainSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DomainSummary.
        The OCID of the identity domain.


        :param id: The id of this DomainSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DomainSummary.
        The OCID of the compartment containing the identity domain.


        :return: The compartment_id of this DomainSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DomainSummary.
        The OCID of the compartment containing the identity domain.


        :param compartment_id: The compartment_id of this DomainSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DomainSummary.
        The mutable display name of the identity domain.


        :return: The display_name of this DomainSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DomainSummary.
        The mutable display name of the identity domain.


        :param display_name: The display_name of this DomainSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this DomainSummary.
        The identity domain description. You can have an empty description.


        :return: The description of this DomainSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DomainSummary.
        The identity domain description. You can have an empty description.


        :param description: The description of this DomainSummary.
        :type: str
        """
        self._description = description

    @property
    def url(self):
        """
        **[Required]** Gets the url of this DomainSummary.
        Region-agnostic identity domain URL.


        :return: The url of this DomainSummary.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this DomainSummary.
        Region-agnostic identity domain URL.


        :param url: The url of this DomainSummary.
        :type: str
        """
        self._url = url

    @property
    def home_region_url(self):
        """
        **[Required]** Gets the home_region_url of this DomainSummary.
        Region-specific identity domain URL.


        :return: The home_region_url of this DomainSummary.
        :rtype: str
        """
        return self._home_region_url

    @home_region_url.setter
    def home_region_url(self, home_region_url):
        """
        Sets the home_region_url of this DomainSummary.
        Region-specific identity domain URL.


        :param home_region_url: The home_region_url of this DomainSummary.
        :type: str
        """
        self._home_region_url = home_region_url

    @property
    def home_region(self):
        """
        **[Required]** Gets the home_region of this DomainSummary.
        The home region for the identity domain.


        :return: The home_region of this DomainSummary.
        :rtype: str
        """
        return self._home_region

    @home_region.setter
    def home_region(self, home_region):
        """
        Sets the home_region of this DomainSummary.
        The home region for the identity domain.


        :param home_region: The home_region of this DomainSummary.
        :type: str
        """
        self._home_region = home_region

    @property
    def replica_regions(self):
        """
        **[Required]** Gets the replica_regions of this DomainSummary.
        The regions where replicas of the identity domain exist.


        :return: The replica_regions of this DomainSummary.
        :rtype: list[oci.identity.models.ReplicatedRegionDetails]
        """
        return self._replica_regions

    @replica_regions.setter
    def replica_regions(self, replica_regions):
        """
        Sets the replica_regions of this DomainSummary.
        The regions where replicas of the identity domain exist.


        :param replica_regions: The replica_regions of this DomainSummary.
        :type: list[oci.identity.models.ReplicatedRegionDetails]
        """
        self._replica_regions = replica_regions

    @property
    def type(self):
        """
        **[Required]** Gets the type of this DomainSummary.
        The type of the identity domain.

        Allowed values for this property are: "DEFAULT", "SECONDARY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this DomainSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DomainSummary.
        The type of the identity domain.


        :param type: The type of this DomainSummary.
        :type: str
        """
        allowed_values = ["DEFAULT", "SECONDARY"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def license_type(self):
        """
        **[Required]** Gets the license_type of this DomainSummary.
        The license type of the identity domain.


        :return: The license_type of this DomainSummary.
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """
        Sets the license_type of this DomainSummary.
        The license type of the identity domain.


        :param license_type: The license_type of this DomainSummary.
        :type: str
        """
        self._license_type = license_type

    @property
    def is_hidden_on_login(self):
        """
        **[Required]** Gets the is_hidden_on_login of this DomainSummary.
        Indicates whether the identity domain is hidden on the sign-in screen or not.


        :return: The is_hidden_on_login of this DomainSummary.
        :rtype: bool
        """
        return self._is_hidden_on_login

    @is_hidden_on_login.setter
    def is_hidden_on_login(self, is_hidden_on_login):
        """
        Sets the is_hidden_on_login of this DomainSummary.
        Indicates whether the identity domain is hidden on the sign-in screen or not.


        :param is_hidden_on_login: The is_hidden_on_login of this DomainSummary.
        :type: bool
        """
        self._is_hidden_on_login = is_hidden_on_login

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DomainSummary.
        Date and time the identity domain was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this DomainSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DomainSummary.
        Date and time the identity domain was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this DomainSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DomainSummary.
        The current state.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DomainSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DomainSummary.
        The current state.


        :param lifecycle_state: The lifecycle_state of this DomainSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DomainSummary.
        Any additional details about the current state of the identity domain.

        Allowed values for this property are: "DEACTIVATING", "ACTIVATING", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_details of this DomainSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DomainSummary.
        Any additional details about the current state of the identity domain.


        :param lifecycle_details: The lifecycle_details of this DomainSummary.
        :type: str
        """
        allowed_values = ["DEACTIVATING", "ACTIVATING", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_details, allowed_values):
            lifecycle_details = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DomainSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DomainSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DomainSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DomainSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DomainSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DomainSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DomainSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DomainSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperationExecResult(object):
    """
    Operation execution result for a single input set.
    """

    #: A constant which can be used with the execution_status property of a OperationExecResult.
    #: This constant has a value of "FAILED"
    EXECUTION_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the execution_status property of a OperationExecResult.
    #: This constant has a value of "SUCCESS"
    EXECUTION_STATUS_SUCCESS = "SUCCESS"

    #: A constant which can be used with the execution_status property of a OperationExecResult.
    #: This constant has a value of "QUEUED"
    EXECUTION_STATUS_QUEUED = "QUEUED"

    #: A constant which can be used with the execution_status property of a OperationExecResult.
    #: This constant has a value of "RUNNING"
    EXECUTION_STATUS_RUNNING = "RUNNING"

    def __init__(self, **kwargs):
        """
        Initializes a new OperationExecResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param execution_status:
            The value to assign to the execution_status property of this OperationExecResult.
            Allowed values for this property are: "FAILED", "SUCCESS", "QUEUED", "RUNNING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type execution_status: str

        :param error_message:
            The value to assign to the error_message property of this OperationExecResult.
        :type error_message: str

        :param metrics:
            The value to assign to the metrics property of this OperationExecResult.
        :type metrics: object

        :param output_values:
            The value to assign to the output_values property of this OperationExecResult.
        :type output_values: list[list[object]]

        :param is_whitelisted_error_message:
            The value to assign to the is_whitelisted_error_message property of this OperationExecResult.
        :type is_whitelisted_error_message: bool

        """
        self.swagger_types = {
            'execution_status': 'str',
            'error_message': 'str',
            'metrics': 'object',
            'output_values': 'list[list[object]]',
            'is_whitelisted_error_message': 'bool'
        }

        self.attribute_map = {
            'execution_status': 'executionStatus',
            'error_message': 'errorMessage',
            'metrics': 'metrics',
            'output_values': 'outputValues',
            'is_whitelisted_error_message': 'isWhitelistedErrorMessage'
        }

        self._execution_status = None
        self._error_message = None
        self._metrics = None
        self._output_values = None
        self._is_whitelisted_error_message = None

    @property
    def execution_status(self):
        """
        Gets the execution_status of this OperationExecResult.
        Status of the operation job for particular set of input.

        Allowed values for this property are: "FAILED", "SUCCESS", "QUEUED", "RUNNING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The execution_status of this OperationExecResult.
        :rtype: str
        """
        return self._execution_status

    @execution_status.setter
    def execution_status(self, execution_status):
        """
        Sets the execution_status of this OperationExecResult.
        Status of the operation job for particular set of input.


        :param execution_status: The execution_status of this OperationExecResult.
        :type: str
        """
        allowed_values = ["FAILED", "SUCCESS", "QUEUED", "RUNNING"]
        if not value_allowed_none_or_none_sentinel(execution_status, allowed_values):
            execution_status = 'UNKNOWN_ENUM_VALUE'
        self._execution_status = execution_status

    @property
    def error_message(self):
        """
        Gets the error_message of this OperationExecResult.
        Error message if execution of operation is failed.


        :return: The error_message of this OperationExecResult.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this OperationExecResult.
        Error message if execution of operation is failed.


        :param error_message: The error_message of this OperationExecResult.
        :type: str
        """
        self._error_message = error_message

    @property
    def metrics(self):
        """
        Gets the metrics of this OperationExecResult.
        Metrics of operation execution job.


        :return: The metrics of this OperationExecResult.
        :rtype: object
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this OperationExecResult.
        Metrics of operation execution job.


        :param metrics: The metrics of this OperationExecResult.
        :type: object
        """
        self._metrics = metrics

    @property
    def output_values(self):
        """
        Gets the output_values of this OperationExecResult.
        List of emitted rows for each OUT/INOUT param.


        :return: The output_values of this OperationExecResult.
        :rtype: list[list[object]]
        """
        return self._output_values

    @output_values.setter
    def output_values(self, output_values):
        """
        Sets the output_values of this OperationExecResult.
        List of emitted rows for each OUT/INOUT param.


        :param output_values: The output_values of this OperationExecResult.
        :type: list[list[object]]
        """
        self._output_values = output_values

    @property
    def is_whitelisted_error_message(self):
        """
        Gets the is_whitelisted_error_message of this OperationExecResult.
        True, if error message should be displayed on UI.


        :return: The is_whitelisted_error_message of this OperationExecResult.
        :rtype: bool
        """
        return self._is_whitelisted_error_message

    @is_whitelisted_error_message.setter
    def is_whitelisted_error_message(self, is_whitelisted_error_message):
        """
        Sets the is_whitelisted_error_message of this OperationExecResult.
        True, if error message should be displayed on UI.


        :param is_whitelisted_error_message: The is_whitelisted_error_message of this OperationExecResult.
        :type: bool
        """
        self._is_whitelisted_error_message = is_whitelisted_error_message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionSummary(object):
    """
    Subscription object which contains the common subscription data.
    """

    #: A constant which can be used with the plan_type property of a SubscriptionSummary.
    #: This constant has a value of "FREE_TIER"
    PLAN_TYPE_FREE_TIER = "FREE_TIER"

    #: A constant which can be used with the plan_type property of a SubscriptionSummary.
    #: This constant has a value of "PAYG"
    PLAN_TYPE_PAYG = "PAYG"

    #: A constant which can be used with the upgrade_state property of a SubscriptionSummary.
    #: This constant has a value of "PROMO"
    UPGRADE_STATE_PROMO = "PROMO"

    #: A constant which can be used with the upgrade_state property of a SubscriptionSummary.
    #: This constant has a value of "SUBMITTED"
    UPGRADE_STATE_SUBMITTED = "SUBMITTED"

    #: A constant which can be used with the upgrade_state property of a SubscriptionSummary.
    #: This constant has a value of "ERROR"
    UPGRADE_STATE_ERROR = "ERROR"

    #: A constant which can be used with the upgrade_state property of a SubscriptionSummary.
    #: This constant has a value of "UPGRADED"
    UPGRADE_STATE_UPGRADED = "UPGRADED"

    #: A constant which can be used with the upgrade_state_details property of a SubscriptionSummary.
    #: This constant has a value of "TAX_ERROR"
    UPGRADE_STATE_DETAILS_TAX_ERROR = "TAX_ERROR"

    #: A constant which can be used with the upgrade_state_details property of a SubscriptionSummary.
    #: This constant has a value of "UPGRADE_ERROR"
    UPGRADE_STATE_DETAILS_UPGRADE_ERROR = "UPGRADE_ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SubscriptionSummary.
        :type id: str

        :param subscription_plan_number:
            The value to assign to the subscription_plan_number property of this SubscriptionSummary.
        :type subscription_plan_number: str

        :param plan_type:
            The value to assign to the plan_type property of this SubscriptionSummary.
            Allowed values for this property are: "FREE_TIER", "PAYG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type plan_type: str

        :param time_start:
            The value to assign to the time_start property of this SubscriptionSummary.
        :type time_start: datetime

        :param ship_to_cust_acct_site_id:
            The value to assign to the ship_to_cust_acct_site_id property of this SubscriptionSummary.
        :type ship_to_cust_acct_site_id: str

        :param ship_to_cust_acct_role_id:
            The value to assign to the ship_to_cust_acct_role_id property of this SubscriptionSummary.
        :type ship_to_cust_acct_role_id: str

        :param bill_to_cust_account_id:
            The value to assign to the bill_to_cust_account_id property of this SubscriptionSummary.
        :type bill_to_cust_account_id: str

        :param is_intent_to_pay:
            The value to assign to the is_intent_to_pay property of this SubscriptionSummary.
        :type is_intent_to_pay: bool

        :param currency_code:
            The value to assign to the currency_code property of this SubscriptionSummary.
        :type currency_code: str

        :param gsi_org_code:
            The value to assign to the gsi_org_code property of this SubscriptionSummary.
        :type gsi_org_code: str

        :param language_code:
            The value to assign to the language_code property of this SubscriptionSummary.
        :type language_code: str

        :param organization_id:
            The value to assign to the organization_id property of this SubscriptionSummary.
        :type organization_id: str

        :param upgrade_state:
            The value to assign to the upgrade_state property of this SubscriptionSummary.
            Allowed values for this property are: "PROMO", "SUBMITTED", "ERROR", "UPGRADED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type upgrade_state: str

        :param upgrade_state_details:
            The value to assign to the upgrade_state_details property of this SubscriptionSummary.
            Allowed values for this property are: "TAX_ERROR", "UPGRADE_ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type upgrade_state_details: str

        :param tax_info:
            The value to assign to the tax_info property of this SubscriptionSummary.
        :type tax_info: oci.osp_gateway.models.TaxInfo

        :param payment_options:
            The value to assign to the payment_options property of this SubscriptionSummary.
        :type payment_options: list[oci.osp_gateway.models.PaymentOption]

        :param payment_gateway:
            The value to assign to the payment_gateway property of this SubscriptionSummary.
        :type payment_gateway: oci.osp_gateway.models.PaymentGateway

        :param billing_address:
            The value to assign to the billing_address property of this SubscriptionSummary.
        :type billing_address: oci.osp_gateway.models.BillingAddress

        :param time_plan_upgrade:
            The value to assign to the time_plan_upgrade property of this SubscriptionSummary.
        :type time_plan_upgrade: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'subscription_plan_number': 'str',
            'plan_type': 'str',
            'time_start': 'datetime',
            'ship_to_cust_acct_site_id': 'str',
            'ship_to_cust_acct_role_id': 'str',
            'bill_to_cust_account_id': 'str',
            'is_intent_to_pay': 'bool',
            'currency_code': 'str',
            'gsi_org_code': 'str',
            'language_code': 'str',
            'organization_id': 'str',
            'upgrade_state': 'str',
            'upgrade_state_details': 'str',
            'tax_info': 'TaxInfo',
            'payment_options': 'list[PaymentOption]',
            'payment_gateway': 'PaymentGateway',
            'billing_address': 'BillingAddress',
            'time_plan_upgrade': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'subscription_plan_number': 'subscriptionPlanNumber',
            'plan_type': 'planType',
            'time_start': 'timeStart',
            'ship_to_cust_acct_site_id': 'shipToCustAcctSiteId',
            'ship_to_cust_acct_role_id': 'shipToCustAcctRoleId',
            'bill_to_cust_account_id': 'billToCustAccountId',
            'is_intent_to_pay': 'isIntentToPay',
            'currency_code': 'currencyCode',
            'gsi_org_code': 'gsiOrgCode',
            'language_code': 'languageCode',
            'organization_id': 'organizationId',
            'upgrade_state': 'upgradeState',
            'upgrade_state_details': 'upgradeStateDetails',
            'tax_info': 'taxInfo',
            'payment_options': 'paymentOptions',
            'payment_gateway': 'paymentGateway',
            'billing_address': 'billingAddress',
            'time_plan_upgrade': 'timePlanUpgrade'
        }

        self._id = None
        self._subscription_plan_number = None
        self._plan_type = None
        self._time_start = None
        self._ship_to_cust_acct_site_id = None
        self._ship_to_cust_acct_role_id = None
        self._bill_to_cust_account_id = None
        self._is_intent_to_pay = None
        self._currency_code = None
        self._gsi_org_code = None
        self._language_code = None
        self._organization_id = None
        self._upgrade_state = None
        self._upgrade_state_details = None
        self._tax_info = None
        self._payment_options = None
        self._payment_gateway = None
        self._billing_address = None
        self._time_plan_upgrade = None

    @property
    def id(self):
        """
        Gets the id of this SubscriptionSummary.
        Subscription id identifier (OCID).


        :return: The id of this SubscriptionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubscriptionSummary.
        Subscription id identifier (OCID).


        :param id: The id of this SubscriptionSummary.
        :type: str
        """
        self._id = id

    @property
    def subscription_plan_number(self):
        """
        **[Required]** Gets the subscription_plan_number of this SubscriptionSummary.
        Subscription plan number.


        :return: The subscription_plan_number of this SubscriptionSummary.
        :rtype: str
        """
        return self._subscription_plan_number

    @subscription_plan_number.setter
    def subscription_plan_number(self, subscription_plan_number):
        """
        Sets the subscription_plan_number of this SubscriptionSummary.
        Subscription plan number.


        :param subscription_plan_number: The subscription_plan_number of this SubscriptionSummary.
        :type: str
        """
        self._subscription_plan_number = subscription_plan_number

    @property
    def plan_type(self):
        """
        Gets the plan_type of this SubscriptionSummary.
        Subscription plan type.

        Allowed values for this property are: "FREE_TIER", "PAYG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The plan_type of this SubscriptionSummary.
        :rtype: str
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """
        Sets the plan_type of this SubscriptionSummary.
        Subscription plan type.


        :param plan_type: The plan_type of this SubscriptionSummary.
        :type: str
        """
        allowed_values = ["FREE_TIER", "PAYG"]
        if not value_allowed_none_or_none_sentinel(plan_type, allowed_values):
            plan_type = 'UNKNOWN_ENUM_VALUE'
        self._plan_type = plan_type

    @property
    def time_start(self):
        """
        Gets the time_start of this SubscriptionSummary.
        Start date of the subscription.


        :return: The time_start of this SubscriptionSummary.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this SubscriptionSummary.
        Start date of the subscription.


        :param time_start: The time_start of this SubscriptionSummary.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def ship_to_cust_acct_site_id(self):
        """
        Gets the ship_to_cust_acct_site_id of this SubscriptionSummary.
        Ship to customer account site address id.


        :return: The ship_to_cust_acct_site_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._ship_to_cust_acct_site_id

    @ship_to_cust_acct_site_id.setter
    def ship_to_cust_acct_site_id(self, ship_to_cust_acct_site_id):
        """
        Sets the ship_to_cust_acct_site_id of this SubscriptionSummary.
        Ship to customer account site address id.


        :param ship_to_cust_acct_site_id: The ship_to_cust_acct_site_id of this SubscriptionSummary.
        :type: str
        """
        self._ship_to_cust_acct_site_id = ship_to_cust_acct_site_id

    @property
    def ship_to_cust_acct_role_id(self):
        """
        Gets the ship_to_cust_acct_role_id of this SubscriptionSummary.
        Ship to customer account role.


        :return: The ship_to_cust_acct_role_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._ship_to_cust_acct_role_id

    @ship_to_cust_acct_role_id.setter
    def ship_to_cust_acct_role_id(self, ship_to_cust_acct_role_id):
        """
        Sets the ship_to_cust_acct_role_id of this SubscriptionSummary.
        Ship to customer account role.


        :param ship_to_cust_acct_role_id: The ship_to_cust_acct_role_id of this SubscriptionSummary.
        :type: str
        """
        self._ship_to_cust_acct_role_id = ship_to_cust_acct_role_id

    @property
    def bill_to_cust_account_id(self):
        """
        Gets the bill_to_cust_account_id of this SubscriptionSummary.
        Bill to customer Account id.


        :return: The bill_to_cust_account_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._bill_to_cust_account_id

    @bill_to_cust_account_id.setter
    def bill_to_cust_account_id(self, bill_to_cust_account_id):
        """
        Sets the bill_to_cust_account_id of this SubscriptionSummary.
        Bill to customer Account id.


        :param bill_to_cust_account_id: The bill_to_cust_account_id of this SubscriptionSummary.
        :type: str
        """
        self._bill_to_cust_account_id = bill_to_cust_account_id

    @property
    def is_intent_to_pay(self):
        """
        Gets the is_intent_to_pay of this SubscriptionSummary.
        Payment intension.


        :return: The is_intent_to_pay of this SubscriptionSummary.
        :rtype: bool
        """
        return self._is_intent_to_pay

    @is_intent_to_pay.setter
    def is_intent_to_pay(self, is_intent_to_pay):
        """
        Sets the is_intent_to_pay of this SubscriptionSummary.
        Payment intension.


        :param is_intent_to_pay: The is_intent_to_pay of this SubscriptionSummary.
        :type: bool
        """
        self._is_intent_to_pay = is_intent_to_pay

    @property
    def currency_code(self):
        """
        Gets the currency_code of this SubscriptionSummary.
        Currency code


        :return: The currency_code of this SubscriptionSummary.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this SubscriptionSummary.
        Currency code


        :param currency_code: The currency_code of this SubscriptionSummary.
        :type: str
        """
        self._currency_code = currency_code

    @property
    def gsi_org_code(self):
        """
        Gets the gsi_org_code of this SubscriptionSummary.
        GSI Subscription external code.


        :return: The gsi_org_code of this SubscriptionSummary.
        :rtype: str
        """
        return self._gsi_org_code

    @gsi_org_code.setter
    def gsi_org_code(self, gsi_org_code):
        """
        Sets the gsi_org_code of this SubscriptionSummary.
        GSI Subscription external code.


        :param gsi_org_code: The gsi_org_code of this SubscriptionSummary.
        :type: str
        """
        self._gsi_org_code = gsi_org_code

    @property
    def language_code(self):
        """
        Gets the language_code of this SubscriptionSummary.
        Language short code (en, de, hu, etc)


        :return: The language_code of this SubscriptionSummary.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this SubscriptionSummary.
        Language short code (en, de, hu, etc)


        :param language_code: The language_code of this SubscriptionSummary.
        :type: str
        """
        self._language_code = language_code

    @property
    def organization_id(self):
        """
        Gets the organization_id of this SubscriptionSummary.
        GSI organization external identifier.


        :return: The organization_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """
        Sets the organization_id of this SubscriptionSummary.
        GSI organization external identifier.


        :param organization_id: The organization_id of this SubscriptionSummary.
        :type: str
        """
        self._organization_id = organization_id

    @property
    def upgrade_state(self):
        """
        Gets the upgrade_state of this SubscriptionSummary.
        Status of the upgrade.

        Allowed values for this property are: "PROMO", "SUBMITTED", "ERROR", "UPGRADED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The upgrade_state of this SubscriptionSummary.
        :rtype: str
        """
        return self._upgrade_state

    @upgrade_state.setter
    def upgrade_state(self, upgrade_state):
        """
        Sets the upgrade_state of this SubscriptionSummary.
        Status of the upgrade.


        :param upgrade_state: The upgrade_state of this SubscriptionSummary.
        :type: str
        """
        allowed_values = ["PROMO", "SUBMITTED", "ERROR", "UPGRADED"]
        if not value_allowed_none_or_none_sentinel(upgrade_state, allowed_values):
            upgrade_state = 'UNKNOWN_ENUM_VALUE'
        self._upgrade_state = upgrade_state

    @property
    def upgrade_state_details(self):
        """
        Gets the upgrade_state_details of this SubscriptionSummary.
        This field is used to describe the Upgrade State in case of error (E.g. Upgrade failure caused by interfacing Tax details- TaxError)

        Allowed values for this property are: "TAX_ERROR", "UPGRADE_ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The upgrade_state_details of this SubscriptionSummary.
        :rtype: str
        """
        return self._upgrade_state_details

    @upgrade_state_details.setter
    def upgrade_state_details(self, upgrade_state_details):
        """
        Sets the upgrade_state_details of this SubscriptionSummary.
        This field is used to describe the Upgrade State in case of error (E.g. Upgrade failure caused by interfacing Tax details- TaxError)


        :param upgrade_state_details: The upgrade_state_details of this SubscriptionSummary.
        :type: str
        """
        allowed_values = ["TAX_ERROR", "UPGRADE_ERROR"]
        if not value_allowed_none_or_none_sentinel(upgrade_state_details, allowed_values):
            upgrade_state_details = 'UNKNOWN_ENUM_VALUE'
        self._upgrade_state_details = upgrade_state_details

    @property
    def tax_info(self):
        """
        Gets the tax_info of this SubscriptionSummary.

        :return: The tax_info of this SubscriptionSummary.
        :rtype: oci.osp_gateway.models.TaxInfo
        """
        return self._tax_info

    @tax_info.setter
    def tax_info(self, tax_info):
        """
        Sets the tax_info of this SubscriptionSummary.

        :param tax_info: The tax_info of this SubscriptionSummary.
        :type: oci.osp_gateway.models.TaxInfo
        """
        self._tax_info = tax_info

    @property
    def payment_options(self):
        """
        Gets the payment_options of this SubscriptionSummary.
        Payment option list of a subscription.


        :return: The payment_options of this SubscriptionSummary.
        :rtype: list[oci.osp_gateway.models.PaymentOption]
        """
        return self._payment_options

    @payment_options.setter
    def payment_options(self, payment_options):
        """
        Sets the payment_options of this SubscriptionSummary.
        Payment option list of a subscription.


        :param payment_options: The payment_options of this SubscriptionSummary.
        :type: list[oci.osp_gateway.models.PaymentOption]
        """
        self._payment_options = payment_options

    @property
    def payment_gateway(self):
        """
        Gets the payment_gateway of this SubscriptionSummary.

        :return: The payment_gateway of this SubscriptionSummary.
        :rtype: oci.osp_gateway.models.PaymentGateway
        """
        return self._payment_gateway

    @payment_gateway.setter
    def payment_gateway(self, payment_gateway):
        """
        Sets the payment_gateway of this SubscriptionSummary.

        :param payment_gateway: The payment_gateway of this SubscriptionSummary.
        :type: oci.osp_gateway.models.PaymentGateway
        """
        self._payment_gateway = payment_gateway

    @property
    def billing_address(self):
        """
        Gets the billing_address of this SubscriptionSummary.

        :return: The billing_address of this SubscriptionSummary.
        :rtype: oci.osp_gateway.models.BillingAddress
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """
        Sets the billing_address of this SubscriptionSummary.

        :param billing_address: The billing_address of this SubscriptionSummary.
        :type: oci.osp_gateway.models.BillingAddress
        """
        self._billing_address = billing_address

    @property
    def time_plan_upgrade(self):
        """
        Gets the time_plan_upgrade of this SubscriptionSummary.
        Date of upgrade/conversion when planType changed from FREE_TIER to PAYG


        :return: The time_plan_upgrade of this SubscriptionSummary.
        :rtype: datetime
        """
        return self._time_plan_upgrade

    @time_plan_upgrade.setter
    def time_plan_upgrade(self, time_plan_upgrade):
        """
        Sets the time_plan_upgrade of this SubscriptionSummary.
        Date of upgrade/conversion when planType changed from FREE_TIER to PAYG


        :param time_plan_upgrade: The time_plan_upgrade of this SubscriptionSummary.
        :type: datetime
        """
        self._time_plan_upgrade = time_plan_upgrade

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Config(object):
    """
    A configuration item, which has a number of mutually exclusive properties that can be used to set specific
    portions of the configuration.
    """

    #: A constant which can be used with the config_type property of a Config.
    #: This constant has a value of "SPAN_FILTER"
    CONFIG_TYPE_SPAN_FILTER = "SPAN_FILTER"

    #: A constant which can be used with the config_type property of a Config.
    #: This constant has a value of "METRIC_GROUP"
    CONFIG_TYPE_METRIC_GROUP = "METRIC_GROUP"

    #: A constant which can be used with the config_type property of a Config.
    #: This constant has a value of "APDEX"
    CONFIG_TYPE_APDEX = "APDEX"

    #: A constant which can be used with the config_type property of a Config.
    #: This constant has a value of "OPTIONS"
    CONFIG_TYPE_OPTIONS = "OPTIONS"

    def __init__(self, **kwargs):
        """
        Initializes a new Config object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.apm_config.models.Options`
        * :class:`~oci.apm_config.models.MetricGroup`
        * :class:`~oci.apm_config.models.ApdexRules`
        * :class:`~oci.apm_config.models.SpanFilter`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Config.
        :type id: str

        :param config_type:
            The value to assign to the config_type property of this Config.
            Allowed values for this property are: "SPAN_FILTER", "METRIC_GROUP", "APDEX", "OPTIONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type config_type: str

        :param time_created:
            The value to assign to the time_created property of this Config.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Config.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Config.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Config.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'config_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'config_type': 'configType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._config_type = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['configType']

        if type == 'OPTIONS':
            return 'Options'

        if type == 'METRIC_GROUP':
            return 'MetricGroup'

        if type == 'APDEX':
            return 'ApdexRules'

        if type == 'SPAN_FILTER':
            return 'SpanFilter'
        else:
            return 'Config'

    @property
    def id(self):
        """
        Gets the id of this Config.
        The `OCID`__ of the configuration item. An OCID is generated
        when the item is created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this Config.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Config.
        The `OCID`__ of the configuration item. An OCID is generated
        when the item is created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this Config.
        :type: str
        """
        self._id = id

    @property
    def config_type(self):
        """
        **[Required]** Gets the config_type of this Config.
        The type of configuration item.

        Allowed values for this property are: "SPAN_FILTER", "METRIC_GROUP", "APDEX", "OPTIONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The config_type of this Config.
        :rtype: str
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """
        Sets the config_type of this Config.
        The type of configuration item.


        :param config_type: The config_type of this Config.
        :type: str
        """
        allowed_values = ["SPAN_FILTER", "METRIC_GROUP", "APDEX", "OPTIONS"]
        if not value_allowed_none_or_none_sentinel(config_type, allowed_values):
            config_type = 'UNKNOWN_ENUM_VALUE'
        self._config_type = config_type

    @property
    def time_created(self):
        """
        Gets the time_created of this Config.
        The time the resource was created, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Config.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Config.
        The time the resource was created, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Config.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Config.
        The time the resource was updated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-13T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Config.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Config.
        The time the resource was updated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-13T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Config.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Config.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Config.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Config.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Config.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Config.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Config.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Config.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Config.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
